@@ -50,7 +50,7 @@ class PrivatednsClient(AbstractClient):
 
 
     def CreatePrivateDNSAccount(self, request):
-        """创建私有域解析账号
+        """跨账号关联VPC时绑定其他账号
 
         :param request: Request instance for CreatePrivateDNSAccount.
         :type request: :class:`tencentcloud.privatedns.v20201028.models.CreatePrivateDNSAccountRequest`
@@ -118,29 +118,6 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DeleteEndPoint(self, request):
-        """删除终端节点
-
-        :param request: Request instance for DeleteEndPoint.
-        :type request: :class:`tencentcloud.privatedns.v20201028.models.DeleteEndPointRequest`
-        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DeleteEndPointResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DeleteEndPoint", params, headers=headers)
-            response = json.loads(body)
-            model = models.DeleteEndPointResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DeletePrivateDNSAccount(self, request):
         """删除私有域解析账号
 
